==> haskell-monad-control-1.0.2.3-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-control
version: 1.0.2.3
id: monad-control-1.0.2.3-7JzgqOE5QdMK1n6qA1B9zU
key: monad-control-1.0.2.3-7JzgqOE5QdMK1n6qA1B9zU
license: BSD-3-Clause
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
author: Bas van Dijk, Anders Kaseorg
homepage: https://github.com/basvandijk/monad-control
synopsis: Lift control operations, like exception catching, through monad transformers
description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.
    .
    See the <http://hackage.haskell.org/package/lifted-base lifted-base>
    package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.
    .
    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.
category: Control
abi: 69e6cbcc316152f03e15a8ee01a3a4a0
exposed: True
exposed-modules:
    Control.Monad.Trans.Control
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-control-1.0.2.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-control-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/monad-control-1.0.2.3
hs-libraries: HSmonad-control-1.0.2.3-7JzgqOE5QdMK1n6qA1B9zU
depends:
    base-4.11.1.0 stm-2.4.5.0 transformers-0.5.5.0
    transformers-base-0.4.5.2-AexAWi6e5nx6jQ9Vfwnuts
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-base-0.4.5.2-AexAWi6e5nx6jQ9Vfwnuts=429c07af1089832867529f5d7ce0e624
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
haddock-interfaces: /usr/share/doc/haskell-monad-control/html/monad-control.haddock
haddock-html: /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-control-1.0.2.3-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-control
version: 1.0.2.3
id: monad-control-1.0.2.3-8qJgo7g8lzF2BtkxCSCnkI
key: monad-control-1.0.2.3-8qJgo7g8lzF2BtkxCSCnkI
license: BSD-3-Clause
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
author: Bas van Dijk, Anders Kaseorg
homepage: https://github.com/basvandijk/monad-control
synopsis: Lift control operations, like exception catching, through monad transformers
description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.
    .
    See the <http://hackage.haskell.org/package/lifted-base lifted-base>
    package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.
    .
    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.
category: Control
abi: 20a8eb22fe1aed2b5899ee3d85a0cb2b
exposed: True
exposed-modules:
    Control.Monad.Trans.Control
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-control-1.0.2.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-control-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/monad-control-1.0.2.3
hs-libraries: HSmonad-control-1.0.2.3-8qJgo7g8lzF2BtkxCSCnkI
depends:
    base-4.11.1.0 stm-2.4.5.0 transformers-0.5.5.0
    transformers-base-0.4.5.2-EvdLB4rIPwW4Mi0YtbCZsZ
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-base-0.4.5.2-EvdLB4rIPwW4Mi0YtbCZsZ=9b46c0c542bc8ac21f832a06a7f8e9d2
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
haddock-interfaces: /usr/share/doc/haskell-monad-control/html/monad-control.haddock
haddock-html: /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
